@@ -1,3 +1,4 @@
+import ctypes
 from typing import List
 
 from floc.floc_go import FLOC_GO
@@ -34,6 +35,10 @@ def sim_hash_string(
         covert_str_list_to_go_slice(domains),
         k_max_numbers_of_bits_in_floc,
     )
-    if sim_hash_result.r1:
-        raise SimHashStringError(sim_hash_result.r1.decode())
+
+    error = ctypes.cast(sim_hash_result.r1, ctypes.c_char_p).value
+    FLOC_GO.freeString(sim_hash_result.r1)
+
+    if error:
+        raise SimHashStringError(error.decode())
     return sim_hash_result.r0  # type: ignore[no-any-return]
